# Tketris

Tketris is Tetris implemented in Python and Tkinter

![Game Screenshot](screenshot.png)

## Installation

NOTE: Works for Python 3

Make sure you have `pip` installed. Type `pip install tketris` to install

## Usage

Just type `python -m tketris` and start playing!

|     Key     |   Control  |
|:-----------:|:----------:|
| Left Arrow  | Move Left  |
| Right Arrow | Move Right |
| Up Arrow    | Rotate     |
| Down Arrow  | Soft Drop  |
